@@ -13,7 +13,7 @@ def uploaded_files(allowed_extensions=None, default_content=None):
     """Lists files located in an upload target directory
     """
     if isfile(CONF_FILE):
-        _DIRECTORY = json.load(file(CONF_FILE)).get("UPLOAD_FOLDER","")
+        _DIRECTORY = json.load(open(CONF_FILE, 'r')).get("UPLOAD_FOLDER","")
     else:
         _DIRECTORY = ""
 
